﻿using System;
using System.Drawing;
using System.Windows.Forms;

using Steema.TeeChart.Drawing;
using Steema.TeeChart.Styles;

namespace TestProject
{
    /// <summary>
    /// 메인 폼
    /// </summary>
    public partial class MainForm : Form
    {
        //////////////////////////////////////////////////////////////////////////////////////////////////// Constructor
        ////////////////////////////////////////////////////////////////////////////////////////// Public

        #region 생성자 - MainForm()

        /// <summary>
        /// 생성자
        /// </summary>
        public MainForm()
        {
            InitializeComponent();

            Text = "TChart 클래스 : Aspect 속성을 사용해 3D 차트 회전시키기";

            this.autoHideCheckBox.Checked = true;

            this.rotateHScrollBar.Minimum = 0;
            this.rotateHScrollBar.Value   = 0;
            this.rotateHScrollBar.Maximum = 360;

            this.elevationHScrollBar.Minimum = 0;
            this.elevationHScrollBar.Value   = 0;
            this.elevationHScrollBar.Maximum = 360;

            this.tChart.Aspect.View3D          = true;
            this.tChart.Aspect.Chart3DPercent  = 25;
            this.tChart.Aspect.Orthogonal      = false;
            this.tChart.Panel.Pen              = new ChartPen(Color.Black);
            this.tChart.Walls.Size             = 5;
            this.tChart.Walls.Left.AutoHide    = true;
            this.tChart.Walls.Right.AutoHide   = true;
            this.tChart.Walls.Right.Visible    = true;
            this.tChart.Walls.Bottom.AutoHide  = true;
            this.tChart.Walls.Back.AutoHide    = true;
            this.tChart.Walls.Back.Transparent = false;

            Line line = new Line(this.tChart.Chart);

            line.FillSampleValues();

            this.autoHideCheckBox.CheckedChanged += autoHideCheckBox_CheckedChanged;
            this.rotateHScrollBar.Scroll         += rotateHScrollBar_Scroll;
            this.elevationHScrollBar.Scroll      += elevationHScrollBar_Scroll;
        }

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Method
        ////////////////////////////////////////////////////////////////////////////////////////// Private
        //////////////////////////////////////////////////////////////////////////////// Event

        #region 자동 숨김 체크 박스 체크 변경시 처리하기 - autoHideCheckBox_CheckedChanged(sender, e)

        /// <summary>
        /// 자동 숨김 체크 박스 체크 변경시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void autoHideCheckBox_CheckedChanged(object sender, EventArgs e)
        {
            this.tChart.Walls.Left.AutoHide   = this.autoHideCheckBox.Checked;
            this.tChart.Walls.Right.AutoHide  = this.autoHideCheckBox.Checked;
            this.tChart.Walls.Back.AutoHide   = this.autoHideCheckBox.Checked;
            this.tChart.Walls.Bottom.AutoHide = this.autoHideCheckBox.Checked;
        }

        #endregion
        #region 회전 수평 스크롤바 스크롤시 처리하기 - rotateHScrollBar_Scroll(sender, e)

        /// <summary>
        /// 회전 수평 스크롤바 스크롤시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void rotateHScrollBar_Scroll(object sender, ScrollEventArgs e)
        {
            this.tChart.Aspect.Rotation = this.rotateHScrollBar.Value;
        }

        #endregion
        #region 고도 수평 스크롤바 스크롤시 처리하기 - elevationHScrollBar_Scroll(sender, e)

        /// <summary>
        /// 고도 수평 스크롤바 스크롤시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void elevationHScrollBar_Scroll(object sender, ScrollEventArgs e)
        {
            this.tChart.Aspect.Elevation = this.elevationHScrollBar.Value;
        }

        #endregion
    }
}